<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>ProjectM4Widget</name>
    <message>
        <location filename="../projectm4widget.cpp" line="163"/>
        <source>&amp;Show Menu</source>
        <translation>&amp;Menüyü Göster</translation>
    </message>
    <message>
        <location filename="../projectm4widget.cpp" line="163"/>
        <source>M</source>
        <translation>M</translation>
    </message>
    <message>
        <location filename="../projectm4widget.cpp" line="165"/>
        <source>&amp;Next Preset</source>
        <translation>&amp;Sonraki Önayar</translation>
    </message>
    <message>
        <location filename="../projectm4widget.cpp" line="165"/>
        <source>N</source>
        <translation>N</translation>
    </message>
    <message>
        <location filename="../projectm4widget.cpp" line="166"/>
        <source>&amp;Previous Preset</source>
        <translation>&amp;Önceki Önayar</translation>
    </message>
    <message>
        <location filename="../projectm4widget.cpp" line="166"/>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <location filename="../projectm4widget.cpp" line="167"/>
        <source>&amp;Shuffle</source>
        <translation>&amp;Karıştırılmış</translation>
    </message>
    <message>
        <location filename="../projectm4widget.cpp" line="167"/>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <location filename="../projectm4widget.cpp" line="168"/>
        <source>&amp;Lock Preset</source>
        <translation>&amp;Önayarı Kilitle</translation>
    </message>
    <message>
        <location filename="../projectm4widget.cpp" line="168"/>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <location filename="../projectm4widget.cpp" line="170"/>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Tam Ekran</translation>
    </message>
    <message>
        <location filename="../projectm4widget.cpp" line="170"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>ProjectMPlugin</name>
    <message>
        <location filename="../projectmplugin.cpp" line="42"/>
        <source>ProjectM</source>
        <translation>ProjectM</translation>
    </message>
</context>
<context>
    <name>ProjectMWidget</name>
    <message>
        <location filename="../projectmwidget.cpp" line="143"/>
        <source>&amp;Help</source>
        <translation>&amp;Yardım</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="143"/>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="144"/>
        <source>&amp;Show Song Title</source>
        <translation>&amp;Şarkı Başlığını Göster</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="144"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="145"/>
        <source>&amp;Show Preset Name</source>
        <translation>&amp;Preset Adını Göster</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="145"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="146"/>
        <source>&amp;Show Menu</source>
        <translation>&amp;Menüyü Göster</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="146"/>
        <source>M</source>
        <translation>M</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="148"/>
        <source>&amp;Next Preset</source>
        <translation>&amp;Sonraki Preset</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="148"/>
        <source>N</source>
        <translation>N</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="149"/>
        <source>&amp;Previous Preset</source>
        <translation>&amp;Önceki Preset</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="149"/>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="150"/>
        <source>&amp;Random Preset</source>
        <translation>&amp;Rastgele Preset</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="150"/>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="151"/>
        <source>&amp;Lock Preset</source>
        <translation>Preset &amp;Kilitle</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="151"/>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="153"/>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Tam Ekran</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="153"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>VisualProjectMFactory</name>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="30"/>
        <source>ProjectM</source>
        <translation>ProjectM</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="50"/>
        <source>About ProjectM Visual Plugin</source>
        <translation>ProjectM Görsel Eklenti Hakkında</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="51"/>
        <source>Qmmp ProjectM Visual Plugin</source>
        <translation>Qmmp ProjectM Görsel Eklentisi</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="52"/>
        <source>This plugin adds projectM visualization</source>
        <translation>Bu eklenti projectM görselliğini ekler</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Yazan: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="54"/>
        <source>Based on libprojectM-qt library</source>
        <translation>librojectM qt kitaplığı temellidir</translation>
    </message>
</context>
</TS>
